@@ -48,13 +48,17 @@ protected:
 
     // Virtual methods
     virtual void fit(const Eigen::Matrix<double, Eigen::Dynamic, 2> &data,
-                     std::string method, double mult) = 0;
+                     std::string method, 
+                     double mult, 
+                     const Eigen::VectorXd& weights) = 0;
 
     virtual double calculate_npars() = 0;
 
     virtual double parameters_to_tau(const Eigen::MatrixXd &parameters) = 0;
 
-    virtual Eigen::VectorXd pdf(
+    Eigen::VectorXd pdf(const Eigen::Matrix<double, Eigen::Dynamic, 2> &u);
+
+    virtual Eigen::VectorXd pdf_raw(
         const Eigen::Matrix<double, Eigen::Dynamic, 2> &u) = 0;
 
     virtual Eigen::VectorXd cdf(
