@@ -8,6 +8,7 @@
 
 #include <vector>
 #include <vinecopulib/bicop/family.hpp>
+#include <Eigen/Dense>
 
 namespace vinecopulib {
 //! @brief A class for controlling fit of bivariate copula models.
@@ -21,6 +22,7 @@ public:
                      std::string nonparametric_method = "quadratic",
                      double nonparametric_mult = 1.0,
                      std::string selection_criterion = "bic",
+                     const Eigen::VectorXd& weights = Eigen::VectorXd(),
                      double psi0 = 0.9,
                      bool preselect_families = true,
                      size_t num_threads = 1);
@@ -28,7 +30,7 @@ public:
     FitControlsBicop(std::string parametric_method);
 
     FitControlsBicop(std::string nonparametric_method,
-                     double nonparametric_mult);
+                     double nonparametric_mult = 1.0);
 
     // Getters
     std::vector <BicopFamily> get_family_set() const;
@@ -40,12 +42,14 @@ public:
     double get_nonparametric_mult() const;
 
     std::string get_selection_criterion() const;
+    
+    Eigen::VectorXd get_weights() const;
 
     bool get_preselect_families() const;
     
     double get_psi0() const;
 
-    size_t get_num_threads();
+    size_t get_num_threads() const;
 
     // Setters
     void set_family_set(std::vector <BicopFamily> family_set);
@@ -57,7 +61,9 @@ public:
     void set_nonparametric_mult(double nonparametric_mult);
 
     void set_selection_criterion(std::string selection_criterion);
-
+    
+    void set_weights(const Eigen::VectorXd& weights);
+    
     void set_preselect_families(bool preselect_families);
     
     void set_psi0(double psi0);
@@ -70,6 +76,7 @@ private:
     std::string nonparametric_method_;
     double nonparametric_mult_;
     std::string selection_criterion_;
+    Eigen::VectorXd weights_;
     bool preselect_families_;
     double psi0_;
     size_t num_threads_;
