@@ -34,7 +34,7 @@ private:
     double generator_derivative2(const double &u);
 
     // pdf
-    Eigen::VectorXd pdf(const Eigen::Matrix<double, Eigen::Dynamic, 2> &u);
+    Eigen::VectorXd pdf_raw(const Eigen::Matrix<double, Eigen::Dynamic, 2> &u);
 
     // link between Kendall's tau and the par_bicop parameter
     Eigen::MatrixXd tau_to_parameters(const double &tau);
