@@ -25,7 +25,7 @@ public:
 
 private:
     // PDF
-    Eigen::VectorXd pdf(
+    Eigen::VectorXd pdf_raw(
         const Eigen::Matrix<double, Eigen::Dynamic, 2> &u
     );
 
