@@ -34,7 +34,7 @@ private:
     double generator_derivative2(const double &u);
 
     // pdf
-    Eigen::VectorXd pdf(const Eigen::Matrix<double, Eigen::Dynamic, 2> &u);
+    Eigen::VectorXd pdf_raw(const Eigen::Matrix<double, Eigen::Dynamic, 2> &u);
 
     // inverse hfunction
     Eigen::VectorXd hinv1(
