@@ -29,9 +29,11 @@ test_that("works with structure", {
     expect_silent(fit <- vinecop(u, structure = matrix(c(1:2, 1:0), 2, 2)))
 })
 
-test_that("runs in parallel", {
-    expect_silent(fit <- vinecop(u, cores = 2))
-})
+if (Sys.info()['sysname'] != "SunOS") {
+    test_that("runs in parallel", {
+        expect_silent(fit <- vinecop(u, cores = 2))
+    })   
+}
 
 test_that("S3 generics work", {
     expect_equal(predict(fit, u), fitted(fit_with_data))
@@ -59,4 +61,4 @@ test_that("truncation works", {
     fit_truncated <- vinecop(u, "par", trunc_lvl = 1)
     expect_silent(dvinecop(u, fit_truncated))
     expect_silent(rvinecop(50, fit_truncated))
-})
\ No newline at end of file
+})
